<?xml version="1.0" encoding="utf-8"?>
<rss version="2.0" xmlns:dc="http://purl.org/dc/elements/1.1/" xmlns:content="http://purl.org/rss/1.0/modules/content/">
    <channel>
        <title>Gax1nnt</title>
        <link>https://paragraph.com/@gax1nnt</link>
        <description>undefined</description>
        <lastBuildDate>Wed, 05 Aug 2026 04:27:08 GMT</lastBuildDate>
        <docs>https://validator.w3.org/feed/docs/rss2.html</docs>
        <generator>https://github.com/jpmonette/feed</generator>
        <language>en</language>
        <image>
            <title>Gax1nnt</title>
            <url>https://storage.googleapis.com/papyrus_images/141e29d2505289c8f9091cf54dfc0e8ec4beaef1a9305e5371efc48415828618.jpg</url>
            <link>https://paragraph.com/@gax1nnt</link>
        </image>
        <copyright>All rights reserved</copyright>
        <item>
            <title><![CDATA[Artela Network’s Economic Model and Tokenomics]]></title>
            <link>https://paragraph.com/@gax1nnt/artela-network-s-economic-model-and-tokenomics</link>
            <guid>jjpCwh0RrYu7xvqyN0Ew</guid>
            <pubDate>Wed, 15 Jan 2025 13:33:18 GMT</pubDate>
            <description><![CDATA[Full original: https://artela.network/blog/artela-tokenomics Artela Network represents a cutting-edge blockchain platform designed to deliver high-performance, modular, and scalable solutions for fully on-chain AI agents. With groundbreaking technological innovations such as full-stack parallelization, multi-VM extensions, and elastic blockspace, Artela pushes the boundaries of blockchain technology while enabling seamless native AI integration. Following years of rigorous engineering develop...]]></description>
            <content:encoded><![CDATA[<p>Full original:</p><p><a target="_blank" rel="noopener noreferrer nofollow ugc" class="dont-break-out" href="https://artela.network/blog/artela-tokenomics">https://artela.network/blog/artela-tokenomics</a></p><p><strong>Artela Network</strong> represents a cutting-edge blockchain platform designed to deliver high-performance, modular, and scalable solutions for fully on-chain AI agents. With groundbreaking technological innovations such as full-stack parallelization, multi-VM extensions, and elastic blockspace, Artela pushes the boundaries of blockchain technology while enabling seamless native AI integration. Following years of rigorous engineering development and months of successful testnet operations, Artela is now ready for its next big step—scaling to support millions of users and AI agents on-chain.</p><p>Today, we are excited to unveil the <strong>tokenomics of Artela</strong>, a comprehensive economic and incentive structure designed to ensure the platform&apos;s sustainability and scalability. The Artela economic model is a forward-looking approach that aligns incentives across all ecosystem participants, fostering a vibrant, thriving digital economy with the capacity to support billions of active participants.</p><hr><h3 id="h-1-art-token-introduction-and-core-functions" class="text-2xl font-header !mt-6 !mb-4 first:!mt-0 first:!mb-0">1. ART Token: Introduction and Core Functions</h3><figure float="none" data-type="figure" class="img-center" style="max-width: null;"><img src="https://storage.googleapis.com/papyrus_images/40890feeb16d9b905ea35bee5509c394305e9c2b06b75da09f2617805f9f1ae1.png" alt="https://artela.network/blog/artela-tokenomics" blurdataurl="data:image/gif;base64,R0lGODlhAQABAIAAAP///wAAACwAAAAAAQABAAACAkQBADs=" nextheight="600" nextwidth="800" class="image-node embed"><figcaption HTMLAttributes="[object Object]" class="">https://artela.network/blog/artela-tokenomics</figcaption></figure><p>The <strong>ART token</strong> is the native asset of the Artela Network, serving as a cornerstone of its operations. Designed to support transaction processing, governance, and decentralized applications, ART plays several critical roles within the ecosystem.</p><h4 id="h-11-key-functions-of-art" class="text-xl font-header !mt-6 !mb-3 first:!mt-0 first:!mb-0">1.1 Key Functions of ART</h4><ol><li><p>**Staking:**ART tokens can be staked to participate in the proof-of-stake (PoS) consensus mechanism. Staking contributes to network security and stability while rewarding participants, thereby encouraging active engagement in network maintenance.</p></li><li><p>**Gas Fee Payment:**ART is used as the currency for gas fees, covering transaction and operation costs within the network. This ensures efficient and optimal resource allocation across the platform.</p></li><li><p>**Governance Power:**ART holders gain governance rights, enabling them to vote on important decisions such as protocol upgrades and resource allocation. This democratic mechanism empowers the community to shape the network’s future.</p></li><li><p>**Liquidity:**As a versatile and liquid asset, ART facilitates seamless transactions and interactions within the Artela ecosystem. This liquidity supports robust economic activity among users and developers.</p></li></ol><p>In essence, ART is not just a token; it is the lifeblood of the Artela Network, driving security, governance, and liquidity while enabling innovation and community participation.</p><hr><h3 id="h-2-staking-governance-and-supply" class="text-2xl font-header !mt-6 !mb-4 first:!mt-0 first:!mb-0">2. Staking, Governance, and Supply</h3><p>Artela Network operates on a proof-of-stake (PoS) consensus mechanism, ensuring efficiency and security through an advanced blockchain infrastructure. Its in-protocol delegation system allows participants to stake ART either as validators or delegators, earning rewards in return. Validators charge delegators a fee, fostering collaboration in maintaining the network.</p><h4 id="h-21-inflation-model" class="text-xl font-header !mt-6 !mb-3 first:!mt-0 first:!mb-0">2.1 Inflation Model</h4><figure float="none" data-type="figure" class="img-center" style="max-width: null;"><img src="https://storage.googleapis.com/papyrus_images/85949ff08853f7bdea8230e077f8128905f719b8df007915a75dc7eec8410450.png" alt="https://artela.network/blog/artela-tokenomics" blurdataurl="data:image/gif;base64,R0lGODlhAQABAIAAAP///wAAACwAAAAAAQABAAACAkQBADs=" nextheight="600" nextwidth="800" class="image-node embed"><figcaption HTMLAttributes="[object Object]" class="">https://artela.network/blog/artela-tokenomics</figcaption></figure><p>ART follows a dynamic inflation model that starts at <strong>8% annually</strong> and decreases by <strong>1% per year</strong> until it reaches a long-term issuance rate of <strong>0%</strong>. This controlled approach provides predictable supply growth, incentivizing early participation while transitioning toward a deflationary model for long-term value preservation.</p><h4 id="h-22-decentralized-governance" class="text-xl font-header !mt-6 !mb-3 first:!mt-0 first:!mb-0">2.2 Decentralized Governance</h4><p>Governance within Artela Network is fully decentralized, empowering ART holders to propose and vote on changes to network parameters. This democratic structure ensures that all community members have a voice in shaping the platform. Detailed guidelines on governance participation are available, enabling active involvement in decision-making processes.</p><h4 id="h-23-art-allocation" class="text-xl font-header !mt-6 !mb-3 first:!mt-0 first:!mb-0">2.3 ART Allocation</h4><figure float="none" data-type="figure" class="img-center" style="max-width: null;"><img src="https://storage.googleapis.com/papyrus_images/68ebb3c823a9d19db7a1b2f9f8b2ed8616a2a3fa916ab5361f66fccf02bff4c4.png" alt="https://artela.network/blog/artela-tokenomics" blurdataurl="data:image/gif;base64,R0lGODlhAQABAIAAAP///wAAACwAAAAAAQABAAACAkQBADs=" nextheight="600" nextwidth="800" class="image-node embed"><figcaption HTMLAttributes="[object Object]" class="">https://artela.network/blog/artela-tokenomics</figcaption></figure><p>The total supply of ART is <strong>1,000,000,000 tokens</strong>, with no additional issuance beyond this fixed amount. Distribution is strategically designed to balance network growth, ecosystem development, and community involvement:</p><ul><li><p><strong>Community (62%)</strong>:</p><ul><li><p><strong>Airdrop (4.5%)</strong>: Rewards for early participants in Artela’s development.</p></li><li><p><strong>Network Staking (28.5%)</strong>: Ensures long-term network security.</p></li><li><p><strong>Ecosystem Development (23%)</strong>: Incentives for AI agent and dApp developers.</p></li><li><p><strong>Community Reserve (6%)</strong>: Funds reserved for future expansion.</p></li></ul></li><li><p><strong>Team (15%)</strong>: Allocation for the core development team.</p></li><li><p><strong>Investors (18%)</strong>: Distributed to institutional and individual investors.</p></li><li><p><strong>Early Contributors (5%)</strong>: Rewards for advisors, partners, and early supporters.</p></li></ul><h4 id="h-24-unlock-schedule" class="text-xl font-header !mt-6 !mb-3 first:!mt-0 first:!mb-0">2.4 Unlock Schedule</h4><figure float="none" data-type="figure" class="img-center" style="max-width: null;"><img src="https://storage.googleapis.com/papyrus_images/10cc62b911edfba267e10c37820d01e93e89ed60af957b2aee25ca1063abfe0c.png" alt="https://artela.network/blog/artela-tokenomics" blurdataurl="data:image/gif;base64,R0lGODlhAQABAIAAAP///wAAACwAAAAAAQABAAACAkQBADs=" nextheight="600" nextwidth="800" class="image-node embed"><figcaption HTMLAttributes="[object Object]" class="">https://artela.network/blog/artela-tokenomics</figcaption></figure><p>The token release schedule is carefully structured to ensure stability and transparency. This controlled unlocking process fosters confidence among ART holders and supports the ecosystem’s sustainable growth. Details of the unlock periods by category are outlined in accompanying charts and tables.</p><hr><h3 id="h-3-conclusion" class="text-2xl font-header !mt-6 !mb-4 first:!mt-0 first:!mb-0">3. Conclusion</h3><p>Artela’s economic model is intricately aligned with its technical architecture to create a scalable and sustainable system capable of supporting billions of users and AI agents. The ART token lies at the core of this vision, enabling security, governance, and liquidity while fostering ecosystem growth. By prioritizing fair initial distributions and a structured release schedule, Artela is laying the foundation for a thriving blockchain economy.</p><p>The journey ahead is full of promise, as the Artela ecosystem evolves and its community grows. Together, we are building a network that redefines the boundaries of blockchain and AI integration.</p>]]></content:encoded>
            <author>gax1nnt@newsletter.paragraph.com (Gax1nnt)</author>
            <enclosure url="https://storage.googleapis.com/papyrus_images/4b7d4c8beaf9846a9820b3555d4abd2fa81e5eae83170c8069b17134d4a8eff3.png" length="0" type="image/png"/>
        </item>
        <item>
            <title><![CDATA[Cysic Labs Projects]]></title>
            <link>https://paragraph.com/@gax1nnt/cysic-labs-projects</link>
            <guid>8ibScahl7aYYZ5Q82XAE</guid>
            <pubDate>Thu, 29 Aug 2024 12:50:16 GMT</pubDate>
            <description><![CDATA[Introduction Cysic Labs offers tools for working with cryptography, especially zero-knowledge proofs (ZKPs) and elliptic curves. This guide will walk you through setting up and using these tools with practical examples.Installation Clone the desired repository:git clone https://github.com/cysic-labs/&#x3C;repository-name> cd &#x3C;repository-name> cargo build 3. Working with Elliptic Curves Use elliptic curve operations in Rust:use elliptic_curve::scalar::Scalar; fn main() { let a = Scalar::f...]]></description>
            <content:encoded><![CDATA[<ol><li><p><strong>Introduction</strong> Cysic Labs offers tools for working with cryptography, especially zero-knowledge proofs (ZKPs) and elliptic curves. This guide will walk you through setting up and using these tools with practical examples.</p></li><li><p><strong>Installation</strong> Clone the desired repository:</p></li></ol><pre data-type="codeBlock" text="git clone https://github.com/cysic-labs/&lt;repository-name&gt;
cd &lt;repository-name&gt;
cargo build
"><code>git clone https:<span class="hljs-comment">//github.com/cysic-labs/&#x3C;repository-name></span>
cd <span class="hljs-operator">&#x3C;</span>repository<span class="hljs-operator">-</span>name<span class="hljs-operator">></span>
cargo build
</code></pre><p><strong>3. Working with Elliptic Curves</strong></p><p>Use elliptic curve operations in Rust:</p><pre data-type="codeBlock" text="use elliptic_curve::scalar::Scalar;

fn main() {
    let a = Scalar::from(123);
    let b = Scalar::from(456);
    let result = a * b;
    println!(&quot;Multiplication result: {:?}&quot;, result);
}
"><code>use elliptic_curve::scalar::Scalar;

fn <span class="hljs-selector-tag">main</span>() {
    let <span class="hljs-selector-tag">a</span> = Scalar::<span class="hljs-built_in">from</span>(<span class="hljs-number">123</span>);
    let <span class="hljs-selector-tag">b</span> = Scalar::<span class="hljs-built_in">from</span>(<span class="hljs-number">456</span>);
    let result = <span class="hljs-selector-tag">a</span> * <span class="hljs-selector-tag">b</span>;
    println!("Multiplication result: {:?}", result);
}
</code></pre><p><strong>4. Implementing Zero-Knowledge Proofs</strong></p><p>Create and verify a ZKP:</p><pre data-type="codeBlock" text="use zkp_toolkit::{Prover, Verifier};

fn main() {
    let (proof, public_input) = Prover::new().prove();
    let is_valid = Verifier::new().verify(proof, public_input);
    println!(&quot;Proof is valid: {:?}&quot;, is_valid);
}
"><code>use zkp_toolkit::{Prover, Verifier};

fn <span class="hljs-selector-tag">main</span>() {
    let (proof, public_input) = Prover::<span class="hljs-built_in">new</span>().<span class="hljs-built_in">prove</span>();
    let is_valid = Verifier::<span class="hljs-built_in">new</span>().<span class="hljs-built_in">verify</span>(proof, public_input);
    println!("Proof is valid: {:?}", is_valid);
}
</code></pre><p><strong>5. GPU Parallel Computing</strong></p><p>Utilize CUDA for GPU-based calculations:</p><pre data-type="codeBlock" text="__global__ void multiply_scalar(int *a, int *b, int *result) {
    int idx = threadIdx.x + blockIdx.x * blockDim.x;
    result[idx] = a[idx] * b[idx];
}
"><code>__global__ void multiply_scalar(<span class="hljs-keyword">int</span> <span class="hljs-operator">*</span>a, <span class="hljs-keyword">int</span> <span class="hljs-operator">*</span>b, <span class="hljs-keyword">int</span> <span class="hljs-operator">*</span>result) {
    <span class="hljs-keyword">int</span> idx <span class="hljs-operator">=</span> threadIdx.x <span class="hljs-operator">+</span> blockIdx.x <span class="hljs-operator">*</span> blockDim.x;
    result[idx] <span class="hljs-operator">=</span> a[idx] <span class="hljs-operator">*</span> b[idx];
}
</code></pre>]]></content:encoded>
            <author>gax1nnt@newsletter.paragraph.com (Gax1nnt)</author>
            <enclosure url="https://storage.googleapis.com/papyrus_images/da545d7fe87a991deba417b148d59029596573574814f02b615cbe998d328b6b.jpg" length="0" type="image/jpg"/>
        </item>
        <item>
            <title><![CDATA[Side Protocol: Run a Full Node guide]]></title>
            <link>https://paragraph.com/@gax1nnt/side-protocol-run-a-full-node-guide</link>
            <guid>HUljMMXkY8mPOCtqPYTk</guid>
            <pubDate>Fri, 02 Aug 2024 11:38:39 GMT</pubDate>
            <description><![CDATA[In this simple guide, I will show you how to put a complete Side Protocol project node. I&apos;m sure you will be able to get it up and running quickly if you use my guide! Be sure to subscribe to my social networks, they will be listed at the end of the guide.Run a Full NodeTestnet ConfigurationChain ID: grimoria-testnet-1RPC: https://testnet-rpc.side.oneRest: https://testnet-rest.side.onegRPC: https://testnet-grpc.side.one:443Persistence Nodes: 6bef0693d7a31fed473b95123ad19b544b414093@202.1...]]></description>
            <content:encoded><![CDATA[<p>In this simple guide, I will show you how to put a complete Side Protocol project node. I&apos;m sure you will be able to get it up and running quickly if you use my guide! Be sure to subscribe to my social networks, they will be listed at the end of the guide.</p><h2 id="h-run-a-full-node" class="text-3xl font-header !mt-8 !mb-4 first:!mt-0 first:!mb-0">Run a Full Node</h2><h3 id="h-testnet-configuration" class="text-2xl font-header !mt-6 !mb-4 first:!mt-0 first:!mb-0">Testnet Configuration</h3><ul><li><p>Chain ID: grimoria-testnet-1</p></li><li><p>RPC: <a target="_blank" rel="noopener noreferrer nofollow ugc" class="dont-break-out" href="https://testnet-rpc.side.one/">https://testnet-rpc.side.one</a></p></li><li><p>Rest: <a target="_blank" rel="noopener noreferrer nofollow ugc" class="dont-break-out" href="https://testnet-rest.side.one/">https://testnet-rest.side.one</a></p></li><li><p>gRPC: <a target="_blank" rel="noopener noreferrer nofollow ugc" class="dont-break-out" href="https://testnet-grpc.side.one/">https://testnet-grpc.side.one:443</a></p></li><li><p>Persistence Nodes: <a target="_blank" rel="noopener noreferrer nofollow ugc" class="dont-break-out" href="mailto:6bef0693d7a31fed473b95123ad19b544b414093@202.182.119.24">6bef0693d7a31fed473b95123ad19b544b414093@202.182.119.24</a>:26656,<a target="_blank" rel="noopener noreferrer nofollow ugc" class="dont-break-out" href="mailto:44f8009ed91fddd7ee51117482ede20fb4f33e78@149.28.156.79">44f8009ed91fddd7ee51117482ede20fb4f33e78@149.28.156.79</a>:26656</p></li></ul><h3 id="h-hardware-requirement" class="text-2xl font-header !mt-6 !mb-4 first:!mt-0 first:!mb-0">Hardware Requirement</h3><ul><li><p>CPU: 4 cores</p></li><li><p>RAM: 8 GB</p></li><li><p>Storage: 500 GB</p></li><li><p>Network: 1 Gbps</p></li></ul><h3 id="h-build-sided-from-source-code" class="text-2xl font-header !mt-6 !mb-4 first:!mt-0 first:!mb-0">Build Sided from Source code</h3><pre data-type="codeBlock" text="git clone https://github.com/sideprotocol/side.git
cd side
git checkout v0.9.0
export GOPATH=$HOME/go
export PATH=$PATH:$GOPATH/bin
"><code>git <span class="hljs-built_in">clone</span> https://github.com/sideprotocol/side.git
<span class="hljs-built_in">cd</span> side
git checkout v0.9.0
<span class="hljs-built_in">export</span> GOPATH=<span class="hljs-variable">$HOME</span>/go
<span class="hljs-built_in">export</span> PATH=<span class="hljs-variable">$PATH</span>:<span class="hljs-variable">$GOPATH</span>/bin
</code></pre><p>Compile the sided binary:</p><pre data-type="codeBlock" text="make install
sided version
"><code><span class="hljs-built_in">make</span> install
sided version
</code></pre><h3 id="h-adding-keys-to-the-keyring" class="text-2xl font-header !mt-6 !mb-4 first:!mt-0 first:!mb-0">Adding keys to the keyring</h3><pre data-type="codeBlock" text="sided keys add test --key-type=&quot;segwit&quot;
"><code>sided keys add test <span class="hljs-operator">-</span><span class="hljs-operator">-</span>key<span class="hljs-operator">-</span><span class="hljs-keyword">type</span><span class="hljs-operator">=</span><span class="hljs-string">"segwit"</span>
</code></pre><h3 id="h-initialize-the-node" class="text-2xl font-header !mt-6 !mb-4 first:!mt-0 first:!mb-0">Initialize the Node</h3><pre data-type="codeBlock" text="sided init &lt;MY_SIDE_VALIDATOR&gt; --chain-id=grimoria-testnet-1
"><code>sided init <span class="hljs-operator">&#x3C;</span>MY_SIDE_VALIDATOR<span class="hljs-operator">></span> <span class="hljs-operator">-</span><span class="hljs-operator">-</span>chain<span class="hljs-operator">-</span>id<span class="hljs-operator">=</span>grimoria<span class="hljs-operator">-</span>testnet<span class="hljs-number">-1</span>
</code></pre><h3 id="h-download-the-genesis-file" class="text-2xl font-header !mt-6 !mb-4 first:!mt-0 first:!mb-0">Download The Genesis file</h3><pre data-type="codeBlock" text="wget https://raw.githubusercontent.com/sideprotocol/testnet/main/grimoria-testnet-1/genesis.json -O $HOME/.side/config/genesis.json
"><code>wget https://raw.githubusercontent.com/sideprotocol/testnet/main/grimoria-testnet-1/genesis.json -O <span class="hljs-variable">$HOME</span>/.side/config/genesis.json
</code></pre><h3 id="h-adding-seeds-and-persistent-peers" class="text-2xl font-header !mt-6 !mb-4 first:!mt-0 first:!mb-0">Adding seeds and persistent peers</h3><pre data-type="codeBlock" text="cd $HOME/.side/config
nano config.toml
"><code>cd $HOME<span class="hljs-operator">/</span>.side/config
nano config.toml
</code></pre><pre data-type="codeBlock" text="persistent_peers = &quot;6bef0693d7a31fed473b95123ad19b544b414093@202.182.119.24:26656,44f8009ed91fddd7ee51117482ede20fb4f33e78@149.28.156.79:26656&quot;
"><code><span class="hljs-attr">persistent_peers</span> = <span class="hljs-string">"6bef0693d7a31fed473b95123ad19b544b414093@202.182.119.24:26656,44f8009ed91fddd7ee51117482ede20fb4f33e78@149.28.156.79:26656"</span>
</code></pre><h3 id="h-set-up-min-gas-price" class="text-2xl font-header !mt-6 !mb-4 first:!mt-0 first:!mb-0">Set up min gas price</h3><pre data-type="codeBlock" text="# in app.toml file
minimum-gas-prices = &quot;0.005uside&quot;
"><code># in app.toml file
minimum<span class="hljs-operator">-</span>gas<span class="hljs-operator">-</span>prices <span class="hljs-operator">=</span> <span class="hljs-string">"0.005uside"</span>
</code></pre><h3 id="h-start-node-and-sync" class="text-2xl font-header !mt-6 !mb-4 first:!mt-0 first:!mb-0">Start Node and Sync</h3><pre data-type="codeBlock" text="sided tendermint unsafe-reset-all 
sided start
"><code>sided tendermint unsafe<span class="hljs-operator">-</span>reset<span class="hljs-operator">-</span><span class="hljs-keyword">all</span> 
sided <span class="hljs-keyword">start</span>
</code></pre><h2 id="h-my-links" class="text-3xl font-header !mt-8 !mb-4 first:!mt-0 first:!mb-0">My Links</h2><p>If you found this guide helpful or just liked it, you can learn more about me and subscribe to my social media. Do it, don&apos;t be lazy!</p><p><a target="_blank" rel="noopener noreferrer nofollow ugc" class="dont-break-out" href="https://gax1nnt.gitbook.io/gax1nnt/">https://gax1nnt.gitbook.io/gax1nnt/</a></p><p><a target="_blank" rel="noopener noreferrer nofollow ugc" class="dont-break-out" href="https://x.com/Gax1nnt">https://x.com/Gax1nnt</a></p><p><a target="_blank" rel="noopener noreferrer nofollow ugc" class="dont-break-out" href="https://discord.com/users/846687399262289932">https://discord.com/users/846687399262289932</a></p><p><a target="_blank" rel="noopener noreferrer nofollow ugc" class="dont-break-out" href="https://linktr.ee/Gax1nnt">https://linktr.ee/Gax1nnt</a></p>]]></content:encoded>
            <author>gax1nnt@newsletter.paragraph.com (Gax1nnt)</author>
            <enclosure url="https://storage.googleapis.com/papyrus_images/9991ac9b9e21e7dbf35d2be8cba87cc9eb460a125d2bcf6589f1d73eb9d115e8.png" length="0" type="image/png"/>
        </item>
        <item>
            <title><![CDATA[0g labs: Storage KV guide]]></title>
            <link>https://paragraph.com/@gax1nnt/0g-labs-storage-kv-guide</link>
            <guid>0GYPefflGbdrkxDzayRO</guid>
            <pubDate>Fri, 02 Aug 2024 11:25:11 GMT</pubDate>
            <description><![CDATA[Hi everyone, today we are going to talk about how to put 0g storage KV on your devices. You can just do the steps in this guide and you will definitely succeed! If you like the guide, be sure to subscribe to me on other social networks).Storage KVHardware RequirementMemory: 16 GB RAMCPU: 4 coresDisk: 500GB / 1T NVME SSDBandwidth: 500 MBps for Download / UploadDownload the source codegit clone -b v1.1.0-testnet https://github.com/0glabs/0g-storage-kv.git Buildcd 0g-storage-kv git submodule upd...]]></description>
            <content:encoded><![CDATA[<p>Hi everyone, today we are going to talk about how to put 0g storage KV on your devices. You can just do the steps in this guide and you will definitely succeed! If you like the guide, be sure to subscribe to me on other social networks).</p><h2 id="h-storage-kv" class="text-3xl font-header !mt-8 !mb-4 first:!mt-0 first:!mb-0">Storage KV</h2><h3 id="h-hardware-requirement" class="text-2xl font-header !mt-6 !mb-4 first:!mt-0 first:!mb-0">Hardware Requirement</h3><ul><li><p>Memory: 16 GB RAM</p></li><li><p>CPU: 4 cores</p></li><li><p>Disk: 500GB / 1T NVME SSD</p></li><li><p>Bandwidth: 500 MBps for Download / Upload</p></li></ul><h3 id="h-download-the-source-code" class="text-2xl font-header !mt-6 !mb-4 first:!mt-0 first:!mb-0">Download the source code</h3><pre data-type="codeBlock" text="git clone -b v1.1.0-testnet https://github.com/0glabs/0g-storage-kv.git
"><code>git clone <span class="hljs-operator">-</span>b v1<span class="hljs-number">.1</span><span class="hljs-number">.0</span><span class="hljs-operator">-</span>testnet https:<span class="hljs-comment">//github.com/0glabs/0g-storage-kv.git</span>
</code></pre><h3 id="h-build" class="text-2xl font-header !mt-6 !mb-4 first:!mt-0 first:!mb-0">Build</h3><pre data-type="codeBlock" text="cd 0g-storage-kv
git submodule update --init

# Build in release mode
cargo build --release
"><code>cd 0g<span class="hljs-operator">-</span><span class="hljs-keyword">storage</span><span class="hljs-operator">-</span>kv
git submodule update <span class="hljs-operator">-</span><span class="hljs-operator">-</span>init

# Build in release mode
cargo build <span class="hljs-operator">-</span><span class="hljs-operator">-</span>release
</code></pre><h3 id="h-configure" class="text-2xl font-header !mt-6 !mb-4 first:!mt-0 first:!mb-0">Configure</h3><p>Copy the <code>config_example.toml</code> to <code>config.toml</code> and update the parameters</p><pre data-type="codeBlock" text="# rpc endpoint
rpc_listen_address
# ips of storage service, separated by &quot;,&quot;
zgs_node_urls = &quot;http://ip1:port1,http://ip2:port2,...&quot;

# layer one blockchain rpc endpoint
blockchain_rpc_endpoint

# flow contract address
log_contract_address

# block number to start the sync, better to align with the config in storage service
log_sync_start_block_number

# storage nodes to download data from, separated by &quot;,&quot;
# the provided nodes should cover full data in the storage network
zgs_node_urls
"><code><span class="hljs-comment"># rpc endpoint</span>
rpc_listen_address
<span class="hljs-comment"># ips of storage service, separated by ","</span>
<span class="hljs-attr">zgs_node_urls</span> = <span class="hljs-string">"http://ip1:port1,http://ip2:port2,..."</span>

<span class="hljs-comment"># layer one blockchain rpc endpoint</span>
blockchain_rpc_endpoint

<span class="hljs-comment"># flow contract address</span>
log_contract_address

<span class="hljs-comment"># block number to start the sync, better to align with the config in storage service</span>
log_sync_start_block_number

<span class="hljs-comment"># storage nodes to download data from, separated by ","</span>
<span class="hljs-comment"># the provided nodes should cover full data in the storage network</span>
zgs_node_urls
</code></pre><p>Run the kv service</p><pre data-type="codeBlock" text="cd run

# consider using tmux in order to run in background
../target/release/zgs_kv --config config.toml
"><code>cd run

# consider <span class="hljs-keyword">using</span> <span class="hljs-title">tmux</span> <span class="hljs-title">in</span> <span class="hljs-title">order</span> <span class="hljs-title">to</span> <span class="hljs-title">run</span> <span class="hljs-title">in</span> <span class="hljs-title">background</span>
..<span class="hljs-operator">/</span><span class="hljs-title">target</span><span class="hljs-operator">/</span><span class="hljs-title">release</span><span class="hljs-operator">/</span><span class="hljs-title">zgs_kv</span> <span class="hljs-operator">-</span><span class="hljs-operator">-</span><span class="hljs-title">config</span> <span class="hljs-title">config</span>.<span class="hljs-title">toml</span>
</code></pre><h2 id="h-my-links" class="text-3xl font-header !mt-8 !mb-4 first:!mt-0 first:!mb-0">My Links:</h2><p>If you found this guide helpful or just liked it, you can learn more about me and subscribe to my social media. Do it, don&apos;t be lazy!</p><p><a target="_blank" rel="noopener noreferrer nofollow ugc" class="dont-break-out" href="https://x.com/Gax1nnt">https://x.com/Gax1nnt</a></p><p><a target="_blank" rel="noopener noreferrer nofollow ugc" class="dont-break-out" href="https://discord.com/users/846687399262289932">https://discord.com/users/846687399262289932</a></p><p><a target="_blank" rel="noopener noreferrer nofollow ugc" class="dont-break-out" href="https://linktr.ee/Gax1nnt">https://linktr.ee/Gax1nnt</a></p><p><a target="_blank" rel="noopener noreferrer nofollow ugc" class="dont-break-out" href="https://gax1nnt.gitbook.io/gax1nnt/">https://gax1nnt.gitbook.io/gax1nnt/</a></p>]]></content:encoded>
            <author>gax1nnt@newsletter.paragraph.com (Gax1nnt)</author>
            <enclosure url="https://storage.googleapis.com/papyrus_images/dd17263191e8140e410aa2be3bf1da9478718f14e319fc634a8f9617648dc774.jpg" length="0" type="image/jpg"/>
        </item>
        <item>
            <title><![CDATA[0g labs: Da Node guide]]></title>
            <link>https://paragraph.com/@gax1nnt/0g-labs-da-node-guide</link>
            <guid>yDXTimhaao6DmlSyKDGp</guid>
            <pubDate>Fri, 02 Aug 2024 11:10:33 GMT</pubDate>
            <description><![CDATA[This guide will help you to put Da Node project 0G labs. You just need to follow the simple steps that are listed here, and then you will definitely be able to realize what you have planned. If you liked the guide or me), please visit my social networks and subscribe to them).Da NodeHardware RequirementMemory: 16 GBCPU: 8 coresDisk: 1 TB NVME SSDBandwidth: 100 MBps for Download / UploadInstallationgit clone https://github.com/0glabs/0g-da-node.git git checkout tags/v1.0.1 -b v1.0.1 cargo buil...]]></description>
            <content:encoded><![CDATA[<p>This guide will help you to put Da Node project 0G labs. You just need to follow the simple steps that are listed here, and then you will definitely be able to realize what you have planned. If you liked the guide or me), please visit my social networks and subscribe to them).</p><h2 id="h-da-node" class="text-3xl font-header !mt-8 !mb-4 first:!mt-0 first:!mb-0">Da Node</h2><h3 id="h-hardware-requirement" class="text-2xl font-header !mt-6 !mb-4 first:!mt-0 first:!mb-0">Hardware Requirement</h3><ul><li><p>Memory: 16 GB</p></li><li><p>CPU: 8 cores</p></li><li><p>Disk: 1 TB NVME SSD</p></li><li><p>Bandwidth: 100 MBps for Download / Upload</p></li></ul><h3 id="h-installation" class="text-2xl font-header !mt-6 !mb-4 first:!mt-0 first:!mb-0">Installation</h3><pre data-type="codeBlock" text="git clone https://github.com/0glabs/0g-da-node.git
git checkout tags/v1.0.1 -b v1.0.1
cargo build --release
./dev_support/download_params.sh
"><code>git clone https:<span class="hljs-comment">//github.com/0glabs/0g-da-node.git</span>
git checkout tags<span class="hljs-operator">/</span>v1<span class="hljs-number">.0</span><span class="hljs-number">.1</span> <span class="hljs-operator">-</span>b v1<span class="hljs-number">.0</span><span class="hljs-number">.1</span>
cargo build <span class="hljs-operator">-</span><span class="hljs-operator">-</span>release
./dev_support<span class="hljs-operator">/</span>download_params.sh
</code></pre><h3 id="h-configuration" class="text-2xl font-header !mt-6 !mb-4 first:!mt-0 first:!mb-0">Configuration</h3><p>Create a `config.toml` file:</p><pre data-type="codeBlock" text="log_level = &quot;info&quot;

data_path = &quot;./db/&quot;

# path to downloaded params folder
encoder_params_dir = &quot;params/&quot; 

# grpc server listen address
grpc_listen_address = &quot;0.0.0.0:34000&quot;
# chain eth rpc endpoint
eth_rpc_endpoint = &quot;https://rpc-testnet.0g.ai&quot;
# public grpc service socket address to register in DA contract
# ip:34000 (keep same port as the grpc listen address)
# or if you have dns, fill your dns
socket_address = &quot;&lt;public_ip/dns&gt;:34000&quot;

# data availability contract to interact with
da_entrance_address = &quot;&quot;
# deployed block number of da entrance contract
start_block_number = 0

# signer BLS private key
signer_bls_private_key = &quot;&quot;
# signer eth account private key
signer_eth_private_key = &quot;&quot;

# whether to enable data availability sampling
enable_das = &quot;false&quot;
"><code><span class="hljs-attr">log_level</span> = <span class="hljs-string">"info"</span>

<span class="hljs-attr">data_path</span> = <span class="hljs-string">"./db/"</span>

<span class="hljs-comment"># path to downloaded params folder</span>
<span class="hljs-attr">encoder_params_dir</span> = <span class="hljs-string">"params/"</span> 

<span class="hljs-comment"># grpc server listen address</span>
<span class="hljs-attr">grpc_listen_address</span> = <span class="hljs-string">"0.0.0.0:34000"</span>
<span class="hljs-comment"># chain eth rpc endpoint</span>
<span class="hljs-attr">eth_rpc_endpoint</span> = <span class="hljs-string">"https://rpc-testnet.0g.ai"</span>
<span class="hljs-comment"># public grpc service socket address to register in DA contract</span>
<span class="hljs-comment"># ip:34000 (keep same port as the grpc listen address)</span>
<span class="hljs-comment"># or if you have dns, fill your dns</span>
<span class="hljs-attr">socket_address</span> = <span class="hljs-string">"&#x3C;public_ip/dns>:34000"</span>

<span class="hljs-comment"># data availability contract to interact with</span>
<span class="hljs-attr">da_entrance_address</span> = <span class="hljs-string">""</span>
<span class="hljs-comment"># deployed block number of da entrance contract</span>
<span class="hljs-attr">start_block_number</span> = <span class="hljs-number">0</span>

<span class="hljs-comment"># signer BLS private key</span>
<span class="hljs-attr">signer_bls_private_key</span> = <span class="hljs-string">""</span>
<span class="hljs-comment"># signer eth account private key</span>
<span class="hljs-attr">signer_eth_private_key</span> = <span class="hljs-string">""</span>

<span class="hljs-comment"># whether to enable data availability sampling</span>
<span class="hljs-attr">enable_das</span> = <span class="hljs-string">"false"</span>
</code></pre><p><br>Generate a BLS private key:</p><pre data-type="codeBlock" text="cargo run --bin key-gen
"><code>cargo run <span class="hljs-operator">-</span><span class="hljs-operator">-</span>bin key<span class="hljs-operator">-</span>gen
</code></pre><h3 id="h-run" class="text-2xl font-header !mt-6 !mb-4 first:!mt-0 first:!mb-0">Run</h3><pre data-type="codeBlock" text="./target/release/server --config cargo.toml
"><code>./target<span class="hljs-operator">/</span>release<span class="hljs-operator">/</span>server <span class="hljs-operator">-</span><span class="hljs-operator">-</span>config cargo.toml
</code></pre><h2 id="h-my-links" class="text-3xl font-header !mt-8 !mb-4 first:!mt-0 first:!mb-0">My Links</h2><p>If you found this guide helpful or just liked it, you can learn more about me and subscribe to my social media. Do it, don&apos;t be lazy!</p><p><a target="_blank" rel="noopener noreferrer nofollow ugc" class="dont-break-out" href="https://x.com/Gax1nnt">https://x.com/Gax1nnt</a></p><p><a target="_blank" rel="noopener noreferrer nofollow ugc" class="dont-break-out" href="https://gax1nnt.gitbook.io/gax1nnt/">https://gax1nnt.gitbook.io/gax1nnt/</a></p><p><a target="_blank" rel="noopener noreferrer nofollow ugc" class="dont-break-out" href="https://discord.com/users/846687399262289932">https://discord.com/users/846687399262289932</a></p><p><a target="_blank" rel="noopener noreferrer nofollow ugc" class="dont-break-out" href="https://linktr.ee/Gax1nnt">https://linktr.ee/Gax1nnt</a></p>]]></content:encoded>
            <author>gax1nnt@newsletter.paragraph.com (Gax1nnt)</author>
            <enclosure url="https://storage.googleapis.com/papyrus_images/303a7bd1b22d1fcecf3541db82765901392a626d1d98d2435b9dc973a9a6361c.png" length="0" type="image/png"/>
        </item>
        <item>
            <title><![CDATA[0g labs: Da Retriever guide]]></title>
            <link>https://paragraph.com/@gax1nnt/0g-labs-da-retriever-guide</link>
            <guid>aBqMBtk1SJO3cQJfZoWj</guid>
            <pubDate>Fri, 02 Aug 2024 10:57:22 GMT</pubDate>
            <description><![CDATA[This simple guide will help you put Da Retriever. I won&apos;t tell you what it&apos;s for, because if you went to the guide to start it, you should already know) Subscribe to my social networks, they will be listed at the bottom!Da Retriever InstallationHardware RequirementRAM: 8GBCPU: 2 coresBandwidth: 100 Mbps for download / uploadInstall dependenciessudo apt-get update sudo apt-get install cmake build-essential protobuf-compiler Install Rust:curl --proto '=https' --tlsv1.2 -sSf https://sh...]]></description>
            <content:encoded><![CDATA[<p>This simple guide will help you put Da Retriever. I won&apos;t tell you what it&apos;s for, because if you went to the guide to start it, you should already know) Subscribe to my social networks, they will be listed at the bottom!</p><h2 id="h-da-retriever-installation" class="text-3xl font-header !mt-8 !mb-4 first:!mt-0 first:!mb-0">Da Retriever Installation</h2><h3 id="h-hardware-requirement" class="text-2xl font-header !mt-6 !mb-4 first:!mt-0 first:!mb-0">Hardware Requirement</h3><ul><li><p>RAM: 8GB</p></li><li><p>CPU: 2 cores</p></li><li><p>Bandwidth: 100 Mbps for download / upload</p></li></ul><h3 id="h-install-dependencies" class="text-2xl font-header !mt-6 !mb-4 first:!mt-0 first:!mb-0">Install dependencies</h3><pre data-type="codeBlock" text="sudo apt-get update
sudo apt-get install cmake build-essential protobuf-compiler
"><code>sudo apt<span class="hljs-operator">-</span>get update
sudo apt<span class="hljs-operator">-</span>get install cmake build<span class="hljs-operator">-</span>essential protobuf<span class="hljs-operator">-</span>compiler
</code></pre><p>Install Rust:</p><pre data-type="codeBlock" text="curl --proto &apos;=https&apos; --tlsv1.2 -sSf https://sh.rustup.rs | sh
"><code>curl <span class="hljs-operator">-</span><span class="hljs-operator">-</span>proto <span class="hljs-string">'=https'</span> <span class="hljs-operator">-</span><span class="hljs-operator">-</span>tlsv1<span class="hljs-number">.2</span> <span class="hljs-operator">-</span>sSf https:<span class="hljs-comment">//sh.rustup.rs | sh</span>
</code></pre><p><br>Download the source code:</p><pre data-type="codeBlock" text="git clone https://github.com/0glabs/0g-da-retriever.git
"><code>git <span class="hljs-built_in">clone</span> https://github.com/0glabs/0g-da-retriever.git
</code></pre><h3 id="h-configuration" class="text-2xl font-header !mt-6 !mb-4 first:!mt-0 first:!mb-0">Configuration</h3><blockquote><p>log_level - Set log level.<br>grpc_listen_address - Server listening address.<br>eth_rpc_endpoint - JSON RPC node endpoint for the blockchain network.</p></blockquote><h3 id="h-run" class="text-2xl font-header !mt-6 !mb-4 first:!mt-0 first:!mb-0">Run</h3><p>Build in release mode:</p><pre data-type="codeBlock" text="cargo build --release
"><code>cargo build <span class="hljs-operator">-</span><span class="hljs-operator">-</span>release
</code></pre><p><br>Run retriever:</p><pre data-type="codeBlock" text="./target/release/retriever --config ./run/config.toml
"><code>./target<span class="hljs-operator">/</span>release<span class="hljs-operator">/</span>retriever <span class="hljs-operator">-</span><span class="hljs-operator">-</span>config ./run<span class="hljs-operator">/</span>config.toml
</code></pre><h2 id="h-my-links" class="text-3xl font-header !mt-8 !mb-4 first:!mt-0 first:!mb-0">My Links:</h2><p>If you found this guide helpful or just liked it, you can learn more about me and subscribe to my social media. Do it, don&apos;t be lazy!</p><p><a target="_blank" rel="noopener noreferrer nofollow ugc" class="dont-break-out" href="https://x.com/Gax1nnt">https://x.com/Gax1nnt</a></p><p><a target="_blank" rel="noopener noreferrer nofollow ugc" class="dont-break-out" href="https://linktr.ee/Gax1nnt">https://linktr.ee/Gax1nnt</a></p><p><a target="_blank" rel="noopener noreferrer nofollow ugc" class="dont-break-out" href="https://gax1nnt.gitbook.io/gax1nnt/">https://gax1nnt.gitbook.io/gax1nnt/</a></p><p><a target="_blank" rel="noopener noreferrer nofollow ugc" class="dont-break-out" href="https://discord.com/users/846687399262289932">https://discord.com/users/846687399262289932</a></p>]]></content:encoded>
            <author>gax1nnt@newsletter.paragraph.com (Gax1nnt)</author>
            <enclosure url="https://storage.googleapis.com/papyrus_images/7ea96d6caf2229284168858cf3358c6d65a038571acaa1f40ff675dc7692e144.png" length="0" type="image/png"/>
        </item>
    </channel>
</rss>